library(TraMineR)
library(TraMineRextras)
library(cluster)

findata <- read.table("findata.dat", header = TRUE, na.strings="NAS")
View(findata)
par(mfrow = c(1, 1))
findata.alphabet <- c("Basic pension", "Deceased","Early OA pension","Employed","Full D pension","Inactive","Misfits","NA","OA pension","Part D pension","Unemployed","YoS pension")
findata.labels <- c("Basic pension","Deceased","Early OA pension","Employed","Full D pension","Inactive","Misfits","NA","OA pension","Part D pension","Unemployed","YoS pension")
findata.scodes <- c("bap","DEC","eop","EMP","fdp","INA","MIS","NA","oap","pdp","UNE","yos")
findata <- findata[which(findata$Birth_year == 2000),]
findata.seq <- seqdef(findata, 5:20, xtstep = 1, alphabet = findata.alphabet, states = findata.scodes, labels = findata.labels)
seqlegend(findata.seq)
seqIplot(findata.seq, sortv = "from.start", cex.lab = 0.8, cex.axis = 0.8, cex.legend = 1.3, with.legend = "right", xlab = "Age", xtstep = 1)
seqtab(findata.seq, format = 'SPS', idxs = 1:5)
tr <- seqtrate(findata.seq)*100
round(tr, 1)
seqdplot(findata.seq, group = group.p(findata$Gender), cex.main = 0.9, cex.lab = 0.9, cex.axis = 0.9, with.legend = TRUE, border = NA, xlab = "Age", xtstep = 1)
seqmtplot(findata.seq, group.p(findata$Education), cex.lab = 0.8, cex.axis = 0.6, with.legend = FALSE,  ylim = c(0, 10))
#dist.om <- seqdist(findata.seq, method = "OM", indel = 1, sm = "TRATE")
dist.om <- seqdist(findata.seq, method = "OM", indel = 1, sm = "TRATE")
clusterward <- agnes(dist.om, diss = TRUE, method = "ward")
cl1.4 <- cutree(clusterward, k = 4)
cl1.4fac <- factor(cl1.4, labels = paste("Cluster", 1:4))
par(mfrow = c(2, 2))
seqdplot(findata.seq, group = group.p(cl1.4fac), border = NA, xlab = "Age", cex.main = 0.8, cex.lab = 0.8, cex.axis = 0.8, xtstep = 1)
findata.seq$cl1.4fac <- cl1.4fac
